using Avalonia.Controls;
using ReactiveUI;
using System.Collections.ObjectModel;

namespace AvaloniaApplication3;

public partial class MainWindow : Window
{
    private static readonly Random Random = new();

    public MainWindow()
    {
        InitializeComponent();
        
        var productos = new[] { "Andes IPA", "Andes Roja", "Andes Rubia", "Bondiola Ahumada", "Bife de Chorizo", "Bondiola", "Choripan Ahumado", "Choripan a la Parrilla", "Coca Cola Zero", "Coca Cola", "Ensalada Lechuga y Tomate", "Levite Naranja", "Limon" };

        var pedidos = new ObservableCollection<Pedido>();

        DataContext = pedidos;

        Task.Run(async () =>
        {
            while(true)
            {
                await Task.Delay(TimeSpan.FromSeconds(5));

                pedidos.Add(new Pedido
                {
                    Codigo = 3400 + pedidos.Count,
                    Fecha = DateTime.Now,
                    Items =
                        Enumerable.Range(0, Random.Next(3, 6))
                              .Select(x => productos[Random.Next(0, productos.Length - 1)])
                              .Select(x => new Item(Random.Next(1, 4), x))
                              .ToList()
                });

                foreach (var p in pedidos)
                    p.RaisePropertyChanged(nameof(Pedido.Tiempo));
            }
        });
    }
}

public class Pedido: ReactiveObject
{
    public int Codigo { get; set; }

    public DateTime Fecha { get; set; }

    public string Tiempo => $"Hace {DateTime.Now.Subtract(Fecha).TotalMinutes:00} minutos";

    public List<Item> Items { get; set; } = new();
}

public record Item(int Cantidad, string Descripcion) { }

